@@ -1,15 +1,15 @@
 
 /*
- *  agInit.c  $Id: agInit.c,v 4.6 2006/03/31 19:52:10 bkorb Exp $
+ *  agInit.c  $Id: agInit.c,v 4.10 2007/02/04 17:44:12 bkorb Exp $
  *
- *  Time-stamp:      "2005-12-04 19:42:46 bkorb"
+ *  Time-stamp:      "2007-02-03 17:40:39 bkorb"
  *
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -36,7 +36,7 @@ addSysEnv( char* pzEnvName );
 
 #ifdef DAEMON_ENABLED
  static ag_bool evalProto( tCC** ppzS, uint16_t* pProto );
- static void spawnPipe( const char* pzFile );
+ static void spawnPipe( char const* pzFile );
  static void spawnListens( tCC* pzPort, sa_family_t af );
  static void becomeDaemon( tCC*, tCC*, tCC*, tCC* );
 #endif
@@ -66,13 +66,16 @@ initialize( int arg_ct, char** arg_vec )
     pzLastScheme = NULL;
     procState = PROC_STATE_OPTIONS;
     /*
-     *  Set the last resort search directory first (lowest priority)
+     *  Set the last resort search directories first (lowest priority)
+     *  The lowest of the low is the config time install data dir.
+     *  Next is the *current* directory of this executable.
      */
+    SET_OPT_TEMPL_DIRS( "$@" );
     SET_OPT_TEMPL_DIRS( "$$/../share/autogen" );
 
     {
         char z[ 128 ] = "__autogen__";
-#if defined( HAVE_POSIX_SYSINFO )
+#if defined( HAVE_SOLARIS_SYSINFO )
         static const int nm[] = {
             SI_SYSNAME, SI_HOSTNAME, SI_ARCHITECTURE, SI_HW_PROVIDER,
 #ifdef      SI_PLATFORM
@@ -295,7 +298,7 @@ spawnPipe( tCC* pzFile )
                     continue;
 
                 case -1:
-                    AG_ABEND( aprf(zCannot, errno, "fork", "", strerror(errno)));
+                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, strerror(errno)));
 
                 case 0:
                 }
@@ -383,7 +386,7 @@ spawnPipe( tCC* pzFile )
                     continue;
 
                 case -1:
-                    AG_ABEND( aprf(zCannot, errno, "fork", "", strerror(errno)));
+                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, strerror(errno)));
 
                 case 0:
                 }
@@ -522,7 +525,7 @@ spawnListens( tCC* pzPort, sa_family_t addr_family )
         if (new_conns > 0) {
             switch (fork()) {
             default: continue;
-            case -1: AG_ABEND(aprf(zCannot, errno, "fork", "", strerror(errno)));
+            case -1: AG_ABEND(aprf(zCannot, errno, "fork", zNil,strerror(errno)));
             case 0:  break;
             }
             break;
@@ -638,7 +641,6 @@ becomeDaemon( tCC* pzStdin,
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/agInit.c */
