@@ -1,16 +1,16 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.25 2006/09/28 01:26:33 bkorb Exp $
+ *  $Id: autogen.h,v 4.29 2007/04/28 22:19:23 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-27 11:42:20 bkorb"
- *  Last Committed:    $Date: 2006/09/28 01:26:33 $
+ *  Time-stamp:        "2007-03-25 07:44:02 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  Global header file for AutoGen
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -378,9 +378,9 @@ MODE int         templLineNo      VALUE( 1 );
 MODE tScanCtx*   pBaseCtx         VALUE( NULL );
 MODE tScanCtx*   pCurCtx          VALUE( NULL );
 MODE tScanCtx*   pDoneCtx         VALUE( NULL );
-MODE u_int       endMacLen        VALUE( 0  );
+MODE size_t      endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
-MODE u_int       startMacLen      VALUE( 0  );
+MODE size_t      startMacLen      VALUE( 0  );
 MODE char        zStartMac[  8 ]  VALUE( "" );
 MODE int         guileFailure     VALUE( 0 );
 
@@ -388,7 +388,6 @@ MODE int         guileFailure     VALUE( 0 );
  *  Definition Parsing Globals
  */
 MODE char*       pzDefineData     VALUE( NULL );
-MODE size_t      defineDataSize   VALUE( 0 );
 MODE char*       pz_token         VALUE( NULL );
 MODE te_dp_event lastToken        VALUE( DP_EV_INVALID );
 
@@ -415,19 +414,7 @@ MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
 MKSTRING( Format,     "format" );
-
-/*
- *  It may seem odd that there are two 'nil' strings.  It is used by
- *  evalExpression() to distinguish between an actual value of a zero-
- *  length string, and a defaulted value because there was no value
- *  available.  (In fact, that routine will always select 'zDefaultNil'
- *  except when "runShell()" returns NULL.  A NULL result means an empty
- *  string that is valid (zNil) as opposed to an empty string due to
- *  an unknown value (zDefaultNil).  This distinction is utilized in
- *  the Select_Match_Existence() and Select_Match_NonExistence() functions.
- */
 MKSTRING( Nil,        "" );
-MKSTRING( DefaultNil, "" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
