@@ -1,14 +1,14 @@
 /*
- *  $Id: defFind.c,v 4.11 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: defFind.c,v 4.13 2007/04/28 22:19:23 bkorb Exp $
  *
  *  Time-stamp:        "2006-09-23 19:55:01 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  This module locates definitions.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -37,7 +37,7 @@ typedef struct defEntryList tDefEntryList;
 
 tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
 
-static char zDefinitionName[ MAXPATHLEN ];
+static char zDefinitionName[ AG_PATH_MAX ];
 
 static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
