@@ -1,12 +1,15 @@
-/*  -*- Mode: C -*-
- *
+/*
  *  expFormat.c
- *  $Id: expFormat.c,v 4.10 2006/03/25 19:24:49 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-02-03 10:37:11 bkorb"
+ *  Last Committed:    $Date: 2007/02/04 17:44:12 $
+ *
+ *  $Id: expFormat.c,v 4.21 2007/02/04 17:44:12 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,7 +28,7 @@
  *             Boston, MA  02110-1301, USA.
  */
 
-static const char zGpl[] =
+static char const zGpl[] =
 "%2$s%1$s is free software.\n%2$s\n"
 "%2$sYou may redistribute it and/or modify it under the terms of the\n"
 "%2$sGNU General Public License, as published by the Free Software\n"
@@ -43,7 +46,7 @@ static const char zGpl[] =
 "%2$s\t51 Franklin Street, Fifth Floor\n"
 "%2$s\tBoston, MA  02110-1301, USA.";
 
-static const char zLgpl[] =
+static char const zLgpl[] =
 "%2$s%1$s is free software; you can redistribute it and/or\n"
 "%2$smodify it under the terms of the GNU Lesser General Public\n"
 "%2$sLicense as published by the Free Software Foundation; either\n"
@@ -60,7 +63,7 @@ static const char zLgpl[] =
 "%2$s\t51 Franklin Street, Fifth Floor\n"
 "%2$s\tBoston, MA  02110-1301, USA.";
 
-static const char zBsd[] =
+static char const zBsd[] =
 "%2$s%1$s is free software copyrighted by %3$s.\n%2$s\n"
 "%2$sRedistribution and use in source and binary forms, with or without\n"
 "%2$smodification, are permitted provided that the following conditions\n"
@@ -86,18 +89,18 @@ static const char zBsd[] =
 "%2$sOTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF\n"
 "%2$sADVISED OF THE POSSIBILITY OF SUCH DAMAGE.";
 
-static const char zDne1[] =
+static char const zDne1[] =
 "%s -*- buffer-read-only: t -*- vi: set ro:\n"
 "%s\n";
 
-static const char zDne[] = "%6$s"
+static char const zDne[] = "%6$s"
 "%1$sDO NOT EDIT THIS FILE   (%2$s)\n"
 "%1$s\n"
 "%1$sIt has been AutoGen-ed  %3$s\n"
 "%1$sFrom the definitions    %4$s\n"
 "%1$sand the template file   %5$s";
 
-static const char zDne2[] = "%6$s"
+static char const zDne2[] = "%6$s"
 "%1$sEDIT THIS FILE WITH CAUTION  (%2$s)\n"
 "%1$s\n"
 "%1$sIt has been AutoGen-ed  %3$s\n"
@@ -151,7 +154,7 @@ ag_scm_dne( SCM prefix, SCM first, SCM opt )
     /*
      *  Check for the ``-d'' option
      */
-    if ((pfxLen == 2) && (strncmp( pzPrefix, "-d", 2 ) == 0)) {
+    if ((pfxLen == 2) && (strncmp(pzPrefix, "-d", (size_t)2) == 0)) {
         noDate   = 1;
         pfxLen   = AG_SCM_STRLEN( first );
         pzPrefix = ag_scm2zchars( first, "dne-prefix" );
@@ -179,11 +182,11 @@ ag_scm_dne( SCM prefix, SCM first, SCM opt )
     } else {
         time_t    curTime = time( NULL );
         struct tm*  pTime = localtime( &curTime );
-        strftime( zScribble, 128, "%A %B %e, %Y at %r %Z", pTime );
+        strftime( zScribble, (size_t)128, "%A %B %e, %Y at %r %Z", pTime );
     }
 
     {
-        const char* pz;
+        char const* pz;
         if (! ENABLED_OPT( DEFINITIONS ))
             pz = "<<no definitions>>";
 
@@ -250,14 +253,14 @@ ag_scm_error( SCM res )
     tSCC      zWarn[]   = "Warning";
     tSCC      zBadMsg[] = "??? indecipherable error message ???";
     tCC*      pzMsg;
-    tSuccess  abort = FAILURE;
+    tSuccess  abrt = FAILURE;
     char      zNum[16];
     int       msgLen;
 
     switch (gh_type_e( res )) {
     case GH_TYPE_BOOLEAN:
         if (SCM_FALSEP( res ))
-            abort = PROBLEM;
+            abrt = PROBLEM;
         pzMsg = zNil;
         break;
 
@@ -265,7 +268,7 @@ ag_scm_error( SCM res )
     {
         unsigned long val = gh_scm2ulong( res );
         if (val == 0)
-            abort = PROBLEM;
+            abrt = PROBLEM;
         snprintf( zNum, sizeof( zNum ), "%d", (int)val );
         pzMsg = zNum;
         break;
@@ -274,7 +277,7 @@ ag_scm_error( SCM res )
     case GH_TYPE_CHAR:
         zNum[0] = gh_scm2char( res );
         if ((zNum[0] == NUL) || (zNum[0] == '0'))
-            abort = PROBLEM;
+            abrt = PROBLEM;
         zNum[1] = NUL;
         pzMsg = zNum;
         break;
@@ -290,9 +293,9 @@ ag_scm_error( SCM res )
          *  THEN this is just a warning that is ignored
          */
         if (msgLen <= 0)
-            abort = PROBLEM;
+            abrt = PROBLEM;
         else if (isdigit( *pzMsg ) && (strtol( pzMsg, NULL, 0 ) == 0))
-            abort = PROBLEM;
+            abrt = PROBLEM;
         break;
 
     default:
@@ -304,16 +307,16 @@ ag_scm_error( SCM res )
      *  THEN print it.
      */
     if (*pzMsg != NUL) {
-        char* pz = aprf( zFmt, (abort != PROBLEM) ? zErr : zWarn,
+        char* pz = aprf( zFmt, (abrt != PROBLEM) ? zErr : zWarn,
                          pCurTemplate->pzTplFile, pCurMacro->lineNo,
                          pCurFp->pzOutName, pzMsg );
-        if (abort != PROBLEM)
+        if (abrt != PROBLEM)
             AG_ABEND( pz );
         fputs( pz, pfTrace );
         AGFREE( (void*)pz );
     }
 
-    longjmp( fileAbort, abort );
+    longjmp( fileAbort, abrt );
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -509,13 +512,13 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
 
     {
         tSCC*  apzSfx[] = { "lic", NULL };
-        static char zRealFile[ MAXPATHLEN ];
+        static char zRealFile[ AG_PATH_MAX ];
         char* pzLicense = ag_scm2zchars( license, "license file name" );
 
         /*
          *  Find the template file somewhere
          */
-        if (! SUCCESSFUL( findFile( pzLicense, zRealFile, apzSfx )))
+        if (! SUCCESSFUL( findFile( pzLicense, zRealFile, apzSfx, NULL )))
             AG_ABEND( aprf( zCannot, ENOENT, "map license file", pzLicense,
                             strerror( ENOENT )));
 
@@ -616,14 +619,13 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
          */
         AGFREE( (void*)pzRes );
 
-        return AG_SCM_STR2SCM( pzSaveRes, (pzOut - pzSaveRes) - 1);
+        return AG_SCM_STR2SCM(pzSaveRes, (size_t)((pzOut - pzSaveRes) - 1));
     }
 }
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expFormat.c */
