@@ -1,11 +1,16 @@
 /*
- *  $Id: expGperf.c,v 4.8 2006/03/25 19:24:49 bkorb Exp $
- *  This module implements the expression functions that should
- *  be part of Guile.
+ *  $Id: expGperf.c,v 4.14 2007/04/28 22:19:23 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-11-26 15:35:27 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
+ *
+ *  Create a perfect hash function program and use it to compute
+ *  index values for a list of provided names.  It also documents how
+ *  to incorporate that hashing function into a generated C program.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,13 +55,23 @@ ag_scm_gperf( SCM name, SCM str )
  *       named, @file{gperf_<name>} for use by the gperf function
  *       @xref{SCM gperf}.
  *
- *       This program will be obliterated within a few seconds after
- *       AutoGen exits.
+ *       This program will be obliterated as AutoGen exits.
+ *       However, you may incorporate the generated hashing function
+ *       into your C program with commands something like the following:
+ *
+ *       @example
+ *       [+ (shellf "sed '/^int main(/,$d;/^#line/d' $@{gpdir@}/%s.c"
+ *                  name ) +]
+ *       @end example
+ *
+ *       where @code{name} matches the name provided to this @code{make-perf}
+ *       function.  @code{gpdir} is the variable used to store the name of the
+ *       temporary directory used to stash all the files.
 =*/
 SCM
 ag_scm_make_gperf( SCM name, SCM hlist )
 {
-    SCM     newline  = AG_SCM_STR2SCM( "\n", 1 );
+    SCM     newline  = AG_SCM_STR2SCM("\n", (size_t)1);
     char*   pzName   = ag_scm2zchars( name, "gperf name" );
     char*   pzList;
 
@@ -66,19 +81,17 @@ ag_scm_make_gperf( SCM name, SCM hlist )
     /*
      *  Construct the newline separated list of values
      */
-    hlist = ag_scm_join( newline, hlist );
+    hlist  = ag_scm_join( newline, hlist );
     pzList = ag_scm2zchars( hlist, "hash list" );
 
     /*
      *  Stash the concatenated list somewhere, hopefully without an alloc.
      */
     {
-        static const int makeGperfLine = __LINE__ + 2;
-        static const char* pzCleanup =
-            "(set! shell-cleanup (string-append shell-cleanup "
-            "\"rm -rf ${gpdir}\n\"))\n";
-        char* pzCmd;
-        pzCmd = aprf( zMakeGperf, pzList, pzName );
+        static int  const  makeGperfLine = __LINE__ + 2;
+        static char const* pzCleanup =
+            "(add-cleanup \"rm -rf ${gpdir}\")";
+        char* pzCmd = aprf( zMakeGperf, pzList, pzName );
 
         /*
          *  Run the command and ignore the results.
@@ -86,6 +99,8 @@ ag_scm_make_gperf( SCM name, SCM hlist )
          */
         pzList = runShell( pzCmd );
         AGFREE( pzCmd );
+        if (pzList != NULL)
+            free( pzList );
 
         if (pzCleanup != NULL) {
             (void)ag_scm_c_eval_string_from_file_line(
@@ -142,7 +157,6 @@ ag_scm_gperf( SCM name, SCM str )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expGperf.c */
