@@ -1,8 +1,8 @@
 /*-
- * Copyright (c) 2004-2006
+ * Copyright (c) 2004-2007
  *  Bruce Korb.  All rights reserved.
  *
- * Time-stamp:      "2006-07-15 08:28:08 bkorb"
+ * Time-stamp:      "2006-11-26 15:42:06 bkorb"
  *
  * This code was inspired from software written by
  *   Hanno Mueller, kontakt@hanno.de
@@ -76,7 +76,7 @@
    typedef fpos_t  seek_pos_t;
 
    typedef int     (cookie_read_function_t )(void *, char *, int);
-   typedef int     (cookie_write_function_t)(void *, const char *, int);
+   typedef int     (cookie_write_function_t)(void *, char const *, int);
    typedef fpos_t  (cookie_seek_function_t )(void *, fpos_t, int);
    typedef int     (cookie_close_function_t)(void *);
 
@@ -123,7 +123,7 @@ struct fmem_cookie_s {
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
 static int
-fmem_getmode( const char *pMode, mode_bits_t *pRes );
+fmem_getmode( char const *pMode, mode_bits_t *pRes );
 
 static int
 fmem_extend( fmem_cookie_t *pFMC, size_t new_size );
@@ -141,7 +141,7 @@ static int
 fmem_close( void *cookie );
 /* = = = END-STATIC-FORWARD = = = */
 
-FILE * ag_fmemopen(void *buf, ssize_t len, const char *pMode);
+FILE * ag_fmemopen(void *buf, ssize_t len, char const *pMode);
 int fmem_ioctl( FILE* fp, int req, void* ptr );
 
 #ifdef TEST_FMEMOPEN
@@ -149,7 +149,7 @@ int fmem_ioctl( FILE* fp, int req, void* ptr );
 #endif
 
 static int
-fmem_getmode( const char *pMode, mode_bits_t *pRes )
+fmem_getmode( char const *pMode, mode_bits_t *pRes )
 {
     if (pMode == NULL)
         return 1;
@@ -486,7 +486,7 @@ fmem_ioctl( FILE* fp, int req, void* ptr )
  *  Any other letters following the inital 'a', 'w' or 'r' will cause an error.
 =*/
 FILE *
-ag_fmemopen(void *buf, ssize_t len, const char *pMode)
+ag_fmemopen(void *buf, ssize_t len, char const *pMode)
 {
     fmem_cookie_t *pFMC;
 
@@ -589,7 +589,7 @@ ag_fmemopen(void *buf, ssize_t len, const char *pMode)
         /*
          *  Unallocated file space is set to NULs.  Emulate that.
          */
-        pFMC->buffer = calloc(1, (unsigned)len);
+        pFMC->buffer = calloc((size_t)1, (size_t)len);
         if (pFMC->buffer == NULL) {
             errno = ENOMEM;
             free( pFMC );
@@ -638,7 +638,6 @@ ag_fmemopen(void *buf, ssize_t len, const char *pMode)
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/fmemopen.c */
