@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat Jan 27 07:01:22 PST 2007
+ * Generated Sat May  5 12:03:06 PDT 2007
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -157,10 +157,10 @@ LOCAL tTemplate*
 findTemplate( tCC* pzTemplName );
 
 LOCAL tSuccess
-findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
+findFile(tCC* pzFName, char* pzFullName, tCC** papSuffixList, tCC * pzReferrer);
 
 LOCAL tTemplate*
-loadTemplate( tCC* pzFileName );
+loadTemplate(tCC* pzFileName, tCC * pzReferrer);
 
 LOCAL void
 unloadTemplate( tTemplate* pT );
