@@ -1,11 +1,12 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 4.6 2005/11/07 00:22:05 bkorb Exp $
+ *  $Id: columns.c,v 4.10 2007/04/28 22:19:23 bkorb Exp $
+ *  Time-stamp:        "2006-11-26 16:33:52 bkorb"
  */
 
 /*
- *  Columns copyright 1992-2005 Bruce Korb
+ *  Columns copyright 1992-2007 Bruce Korb
  *
  *  Columns is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,7 +52,7 @@ size_t  columnSz   = 0;
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
-static int
+static uint32_t
 handleIndent( tCC* pzIndentArg );
 
 static void
@@ -113,7 +114,7 @@ main( int    argc,
             } else if (firstSize < indentSize) {
                 char* tmp = malloc( indentSize + 1 );
                 char  z[10];
-                snprintf( z, sizeof(z), "%%-%ds", indentSize );
+                snprintf( z, sizeof(z), "%%-%ds", (int)indentSize );
                 snprintf( tmp, indentSize + 1, z, pzFirstPfx );
                 pzFirstPfx = tmp;
             }
@@ -145,11 +146,11 @@ main( int    argc,
 }
 
 
-static int
+static uint32_t
 handleIndent( tCC* pzIndentArg )
 {
     char* pz;
-    int   colCt = strtol( pzIndentArg, &pz, 0 );
+    uint32_t colCt = strtoul( pzIndentArg, &pz, 0 );
 
     /*
      *  IF the indent argument is a number
@@ -166,7 +167,7 @@ handleIndent( tCC* pzIndentArg )
         /*
          *  Allocate a string to hold the line prefix
          */
-        pzLinePfx = p = malloc( colCt + 1 );
+        pzLinePfx = p = malloc( (size_t)colCt + 1 );
         if (pzLinePfx == NULL) {
             fprintf( stderr, "Cannot malloc %d bytes\n", colCt + 1 );
             exit( EXIT_FAILURE );
@@ -175,7 +176,7 @@ handleIndent( tCC* pzIndentArg )
         /*
          *  Set it to a NUL terminated string of spaces
          */
-        memset( p, ' ', colCt );
+        memset( p, ' ', (size_t)colCt );
         p[ colCt ] = '\0';
 
     } else {
@@ -238,8 +239,8 @@ readLines( void )
      */
     for (;;) {
         char*   pzL;
-        char*   pzText = fgets( zLine, sizeof( zLine ), stdin );
-        int     len;
+        char*   pzText = fgets(zLine, (int)sizeof( zLine ), stdin);
+        size_t  len;
 
         if (pzText == NULL)
             break;
@@ -382,7 +383,7 @@ writeColumns( void )
     tpPrintList pPL;
 
     colCt = columnCt;
-    snprintf( zFmt, sizeof(zFmt), "%%-%ds", columnSz );
+    snprintf(zFmt, sizeof(zFmt), "%%-%ds", (int)columnSz);
 
     if (colCt == 1) {
         writeRows();
@@ -524,7 +525,7 @@ writeRows( void )
     int  colCt;
 
     colCt = columnCt;
-    snprintf( zFmt, sizeof(zFmt), "%%-%ds", columnSz );
+    snprintf(zFmt, sizeof(zFmt), "%%-%ds", (int)columnSz);
 
     /*
      *  IF we have a separator,
@@ -605,15 +606,14 @@ writeRows( void )
 static int
 compProc( const void* p1, const void* p2 )
 {
-    const char* pz1 = *(char* const*)p1;
-    const char* pz2 = *(char* const*)p2;
+    char const* pz1 = *(char* const*)p1;
+    char const* pz2 = *(char* const*)p2;
     return strcmp( pz1, pz2 );
 }
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of columns/columns.c */
