@@ -1,33 +1,32 @@
 /*
- *  $Id: gdinit.c,v 2.9 2004/02/02 03:31:51 bkorb Exp $
+ *  $Id: gdinit.c,v 4.8 2007/04/28 22:19:23 bkorb Exp $
  *
- *    getdefs copyright 1999-2004 Bruce Korb
+ *    getdefs copyright 1999-2007 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Maintainer:        Bruce Korb <bkorb@gnu.org>
- *  Created:           Sat Dec 1, 2001
- *  Last Modified:     $Date: 2004/02/02 03:31:51 $
+ *  Time-stamp:        "2007-04-28 11:31:58 bkorb"
+ *  Last Modified:     $Date: 2007/04/28 22:19:23 $
  *            by: bkorb
  */
 
 tSCC zNoList[] = "ERROR:  block attr must have name list:\n\t%s\n";
 
-/* FORWARD */
-
-STATIC char*
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static char*
 compressOptionText( char* pzS, char* pzE );
 
-STATIC char*
+static char*
 fixupSubblockString( tCC* pzSrc );
 
-STATIC void
+static void
 loadStdin( void );
-/* END-FORWARD */
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  compressOptionText
  */
-STATIC char*
+static char*
 compressOptionText( char* pzS, char* pzE )
 {
     char* pzR = pzS;  /* result      */
@@ -57,7 +56,7 @@ compressOptionText( char* pzS, char* pzE )
         size_t len = (pzD - pzR);
         pzD = malloc( len + 1 );
         if (pzD == NULL) {
-            fprintf( stderr, "cannot dup %d byte string\n", pzD - pzR );
+            fprintf(stderr, "cannot dup %d byte string\n", (int)(pzD - pzR));
             exit( EXIT_FAILURE );
         }
 
@@ -76,7 +75,7 @@ compressOptionText( char* pzS, char* pzE )
 /*
  *  fixupSubblockString
  */
-STATIC char*
+static char*
 fixupSubblockString( tCC* pzSrc )
 {
     char*   pzString;
@@ -164,7 +163,7 @@ fixupSubblockString( tCC* pzSrc )
  *  the first 4096 bytes of a comment line.  So, rather than all these
  *  problems, we just choke on it.
  */
-STATIC void
+static void
 loadStdin( void )
 {
     char z[ 4096 ];
@@ -177,7 +176,7 @@ loadStdin( void )
         USAGE( EXIT_FAILURE );
     }
 
-    while (fgets( z, sizeof( z ), stdin ) != NULL) {
+    while (fgets(z, (int)sizeof(z), stdin) != NULL) {
         char* pz = z + strlen( z );
 
         if (pz[-1] != '\n') {
@@ -209,7 +208,7 @@ loadStdin( void )
  *  and "=\*\/" as a single option.  If that option is the SUBBLOCK
  *  option, it will need to be massaged for use.
  */
-EXPORT void
+LOCAL void
 processEmbeddedOptions( char* pzText )
 {
     tSCC zStStr[] = "/*=--";
@@ -256,7 +255,7 @@ processEmbeddedOptions( char* pzText )
  *     (if we are to use these things).
  *  -  Initialize the user name characters array.
  */
-EXPORT void
+LOCAL void
 validateOptions( void )
 {
     /*
@@ -273,7 +272,7 @@ validateOptions( void )
         char*  bf  = malloc( len );
 
         if (bf == NULL) {
-            fprintf( stderr, zMallocErr, len, "definition pattern" );
+            fprintf( stderr, zMallocErr, (int)len, "definition pattern" );
             exit( EXIT_FAILURE );
         }
 
@@ -291,7 +290,7 @@ validateOptions( void )
      */
     {
         char zRER[ MAXNAMELEN ];
-        static const char zReErr[] =
+        static char const zReErr[] =
             "Regex error %d (%s):  Cannot compile reg expr:\n\t%s\n";
 
         int rerr = regcomp( &define_re, pzDefPat, REG_EXTENDED | REG_ICASE );
@@ -369,7 +368,7 @@ validateOptions( void )
      *       IF we cannot load the file,
      *       THEN it must be new or empty.  Allocate several K to start.
      */
-    if (   HAVE_OPT( ORDERING )
+    if (  HAVE_OPT( ORDERING )
        && (OPT_ARG( ORDERING ) != NULL)) {
         tSCC zIndexPreamble[] =
             "# -*- buffer-read-only: t -*- vi: set ro:\n"
@@ -377,8 +376,7 @@ validateOptions( void )
 
         pzIndexText = loadFile( OPT_ARG( ORDERING ));
         if (pzIndexText == NULL) {
-            pzIndexText = pzEndIndex  = pzIndexEOF =
-                (char*)malloc( 0x4000 );
+            pzIndexText = pzEndIndex = pzIndexEOF = malloc( (size_t)0x4000 );
             indexAlloc = 0x4000;
             pzEndIndex += sprintf( pzEndIndex, "%s", zIndexPreamble );
         } else {
@@ -394,11 +392,15 @@ validateOptions( void )
         strequate( "_-^" );
     }
 
-    if (OPT_ARG( SRCFILE ) == NULL)
-        OPT_ARG( SRCFILE ) = "srcfile";
+    {
+        char const * pz = OPT_ARG( SRCFILE );
+        if ((pz == NULL) || (*pz == NUL))
+            OPT_ARG( SRCFILE ) = "srcfile";
 
-    if (OPT_ARG( LINENUM ) == NULL)
-        OPT_ARG( LINENUM ) = "linenum";
+        pz = OPT_ARG( LINENUM );
+        if ((pz == NULL) || (*pz == NUL))
+            OPT_ARG( LINENUM ) = "linenum";
+    }
 
     {
         tSCC zAgNameChars[] = "abcdefghijklmnopqrstuvwxyz"
@@ -420,7 +422,6 @@ validateOptions( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of getdefs/gdinit.c */
