@@ -1,9 +1,9 @@
 /*
- *  $Id: getdefs.c,v 4.4 2005/11/07 00:22:05 bkorb Exp $
+ *  $Id: getdefs.c,v 4.9 2007/04/28 22:19:23 bkorb Exp $
  *
- *    getdefs copyright 1999-2005 Bruce Korb
+ *    getdefs copyright 1999-2007 Bruce Korb
  *
- *  Time-stamp:        "2005-10-29 12:15:56 bkorb"
+ *  Time-stamp:        "2007-04-28 11:36:13 bkorb"
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  Maintainer:        Bruce Korb <bkorb@gnu.org>
  *  Created:           Mon Jun 30 15:35:12 1997
@@ -612,7 +612,7 @@ doPreamble( FILE* outFp )
         tSCC   zFmt[] = "%-12s = '%s';\n";
         tCC*   pzName = OPT_ARG( FILELIST );
 
-        if (pzName == NULL)
+        if ((pzName == NULL) || (*pzName == NUL))
             pzName = "infile";
 
         if (HAVE_OPT( INPUT )) {
@@ -698,7 +698,7 @@ loadFile( tCC* pzFname )
         if (rdsz < 16) {
             fprintf( stderr, "Error file %s only contains %d bytes.\n"
                      "\tit cannot contain autogen definitions\n",
-                     pzFname, rdsz );
+                     pzFname, (int)rdsz );
             exit( EXIT_FAILURE );
         }
     }
@@ -709,7 +709,7 @@ loadFile( tCC* pzFname )
     pzRead = pzText = (char*)malloc( rdsz + 1 );
     if (pzText == NULL) {
         fprintf( stderr, "Error: could not allocate %d bytes\n",
-                 rdsz + 1 );
+                 (int)rdsz + 1 );
         exit( EXIT_FAILURE );
     }
 
@@ -717,7 +717,7 @@ loadFile( tCC* pzFname )
      *  Read as much as we can get until we have read the file.
      */
     do  {
-        size_t rdct = fread( (void*)pzRead, 1, rdsz, fp );
+        size_t rdct = fread( (void*)pzRead, (size_t)1, rdsz, fp );
 
         if (rdct == 0) {
             fprintf( stderr, "Error %d (%s) reading file %s\n",
@@ -787,9 +787,9 @@ processFile( tCC* pzFile )
     while ( pzScan = pzNext,
             regexec( &define_re, pzScan, COUNT(matches), matches, 0 ) == 0) {
 
-        static const char zNoEnd[] =
+        static char const zNoEnd[] =
             "Error:  definition in %s at line %d has no end\n";
-        static const char zNoSubexp[] =
+        static char const zNoSubexp[] =
             "Warning: entry type not found on line %d in %s:\n\t%s\n";
 
         int  linesInDef = 0;
@@ -798,7 +798,7 @@ processFile( tCC* pzFile )
          *  Make sure there is a subexpression match!!
          */
         if (matches[1].rm_so == -1) {
-            char* pz;
+            char* pz = NULL;
             char  ch = NUL;
 
             pzDef = pzScan + matches[0].rm_so;
@@ -806,11 +806,10 @@ processFile( tCC* pzFile )
                 pz  = pzDef + 30;
                 ch  = *pz;
                 *pz = NUL;
-            } else
-                ch  = NUL;
+            }
 
             fprintf( stderr, zNoSubexp, lineNo, pzFile, pzDef );
-            if (ch != NUL)
+            if (pz != NULL)
                 *pz = ch;
             continue;
         }
@@ -863,7 +862,7 @@ processFile( tCC* pzFile )
                                           blkAllocCt * sizeof( char* ));
             if (papzBlocks == (char**)NULL) {
                 fprintf( stderr, "Realloc error for %d pointers\n",
-                         blkAllocCt );
+                         (int)blkAllocCt );
                 exit( EXIT_FAILURE );
             }
         }
@@ -1173,7 +1172,7 @@ updateDatabase( void )
         exit( EXIT_FAILURE );
     }
 
-    fwrite( pzIndexEOF, (pzEndIndex - pzIndexEOF), 1, fp );
+    fwrite( pzIndexEOF, (size_t)(pzEndIndex - pzIndexEOF), (size_t)1, fp );
     fclose( fp );
     chmod( OPT_ARG( ORDERING ), 0444 );
 }
@@ -1182,7 +1181,6 @@ updateDatabase( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of getdefs/getdefs.c */
