@@ -1,12 +1,21 @@
 #! /bin/sh
 
-# Time-stamp: "2006-06-03 13:14:27 bkorb"
-# Version:    "$Revision: 4.6 $
+## mkgnudoc.sh --   create a native package
+## Copyright (c):   2003-2007 by Bruce Korb
+## Time-stamp:      "2007-04-01 04:21:07 bkorb"
+##              by: bkorb
+## ---------------------------------------------------------------------
+## $Id: mkgnudoc.sh,v 4.10 2007/04/01 20:43:42 bkorb Exp $
+## ---------------------------------------------------------------------
+## Code:
+
+scriptdir=`dirname $0`
+test -f ${scriptdir}/pkg-env && . ${scriptdir}/pkg-env
 
 MAKE=${MAKE:-make}
 pkgsrcdir=`dirname $0`
 pkgsrcdir=`cd ${pkgsrcdir} ; pwd`
-pkg=autogen
+pkg=${PACKAGE_TARNAME}
 ver="${PACKAGE_VERSION}"
 
 set -x
@@ -97,6 +106,7 @@ autogen --base-name=${pkg} -T ${pkgsrcdir}/gnudoc.tpl - <<- _EODefs_
 	title   = '${PACKAGE} - ${*}';
 	project = '${PACKAGE}';
 	version = '${ver}';
+	package = '${pkg}';
 	_EODefs_
 
 rm -f TAG
@@ -105,8 +115,8 @@ tar cf - ${ddir} | gzip > ${ddir}-doc.tar.gz
 
 ## Local Variables:
 ## Mode: shell-script
-## tab-width: 4
 ## indent-tabs-mode: nil
 ## sh-indentation: 2
 ## sh-basic-offset: 2
 ## End:
+## mkgnudoc.sh ends here
